@@ -4,5 +4,6 @@ mod ping;
 mod unix;
 
 pub use error::SurgeError;
-pub use icmp::EchoReply;
+pub use icmp::icmpv4::Icmpv4Packet;
+pub use icmp::IcmpPacket;
 pub use ping::Pinger;
